<?php
/**
 * Refunds email (plain) file
 *
 * @package WC_Advanced_Notifications
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// translators: %s is a recipient name.
printf( esc_html__( 'Hi %s,', 'woocommerce-advanced-notifications' ), esc_html( $recipient_name ) );

echo "\n\n";

// translators: %s is an order number.
printf( esc_html__( 'Order: %s has been refunded.', 'woocommerce-advanced-notifications' ), esc_html( $order->get_order_number() ) );

echo "\n\n";

echo "============================================================\n";

$order_date_display = wc_format_datetime( $order->get_date_created() );
printf( '%s', esc_html( $order_date_display ) );

echo "\n";

echo '============================================================';

$displayed_total = 0;

foreach ( $order->get_items() as $item_id => $item ) {

	if ( is_callable( array( $item, 'get_product' ) ) ) {
		$_product = $item->get_product();
	} else {
		$_product = $order->get_product_from_item( $item );
	}

	$display = false;

	$product_id = $_product->is_type( 'variation' ) ? $_product->get_parent_id() : $_product->get_id();

	if ( $triggers['all'] || in_array( $product_id, array_map( 'intval', $triggers['product_ids'] ), true ) || in_array( $_product->get_shipping_class_id(), array_map( 'intval', $triggers['shipping_classes'] ), true ) ) {
		$display = true;
	}

	if ( ! $display ) {

		$cats = wp_get_post_terms( $product_id, 'product_cat', array( 'fields' => 'ids' ) );

		if ( count( array_intersect( $cats, $triggers['product_cats'] ) ) > 0 ) {
			$display = true;
		}
	}

	if ( ! $display && ! empty( $show_all_items ) ) {
		$display = true;
	}

	if ( ! $display ) {
		continue;
	}

	$displayed_total += $order->get_line_total( $item, true );

	$item_meta = new WC_Order_Item_Product( $item_id );

	/**
	 * Allow other plugins to modify product title.
	 *
	 * @since 1.2.0
	 */
	$product_name = apply_filters( 'woocommerce_order_product_title', $item['name'], $_product );
	echo "\n" . esc_html( html_entity_decode( wp_strip_all_tags( $product_name ), ENT_COMPAT ) );

	// SKU.
	echo $_product->get_sku() ? ' (#' . esc_html( html_entity_decode( wp_strip_all_tags( $_product->get_sku() ), ENT_COMPAT ) ) . ')' : '';

	if ( $show_prices ) {
		echo ' (' . esc_html( html_entity_decode( wp_strip_all_tags( $order->get_line_subtotal( $item ) ), ENT_COMPAT ) ) . ')';
	}

	echo ' X ' . esc_html( html_entity_decode( wp_strip_all_tags( $item['qty'] ), ENT_COMPAT ) );

	/**
	 * Allow other plugins to add additional product information here.
	 *
	 * @since 1.2.0
	 */
	do_action( 'woocommerce_order_item_meta_start', $item_id, $item, $order, $plain_text );

	// Variation.
	$stripped_item_meta = wp_strip_all_tags(
		wc_display_item_meta(
			$item,
			array(
				'before'    => "\n- ",
				'separator' => "\n- ",
				'after'     => '',
				'echo'      => false,
				'autop'     => false,
			)
		)
	);

	echo esc_html( $stripped_item_meta );

	// File URLs.
	if ( $show_download_links ) {
		wc_display_item_downloads( $item );
	}

	/**
	 * Allow other plugins to add additional product information here.
	 *
	 * @since 1.2.0
	 */
	do_action( 'woocommerce_order_item_meta_end', $item_id, $item, $order, $plain_text );

	echo "\n";

}

echo "============================================================\n";

if ( $show_totals ) {

	$_totals = $order->get_order_item_totals();
	if ( $_totals ) {
		foreach ( $_totals as $total ) {
			echo esc_html( html_entity_decode( wp_strip_all_tags( $total['label'] ), ENT_COMPAT ) ) . ' ';
			echo esc_html( html_entity_decode( wp_strip_all_tags( $total['value'] ), ENT_COMPAT ) );
			echo "\n";
		}
	} else {
		// Only show the total for displayed items.
		echo esc_html__( 'Total', 'woocommerce-advanced-notifications' ) . ': ';
		echo esc_html( html_entity_decode( wp_strip_all_tags( $displayed_total ), ENT_COMPAT ) );
		echo "\n";
	}
}

if ( $order->get_customer_note() ) {
	echo esc_html__( 'Note', 'woocommerce-advanced-notifications' ) . ': ';
	echo esc_html( html_entity_decode( wp_strip_all_tags( $order->get_customer_note() ), ENT_COMPAT ) );
	echo "\n";
}

echo "\n\n";

/**
 * Hook to add more display after customer details.
 *
 * @hooked WC_Emails::customer_details() Shows customer details
 * @hooked WC_Emails::email_address() Shows email address
 *
 * @since 1.2.0
 */
do_action( 'woocommerce_email_customer_details', $order, $sent_to_admin, $plain_text, $email );

echo "\n\n";

echo "Regards,\n" . esc_html( html_entity_decode( wp_strip_all_tags( $blogname ), ENT_COMPAT ) );
